import argparse
from pageshot.converter import to_png
from pygments import highlight
from pygments.formatters import HtmlFormatter, ImageFormatter
from pygments.lexers import PythonLexer

def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("--url", help="page url", dest="url")
    parser.add_argument("--outfile", help="output image location", dest="outfile")
    args = parser.parse_args()

    if args.url is None:
        parser.error("--url requires an argument")

    url = args.url
    outfile = args.outfile if args.outfile is not None else "page.png"
    to_png(url, outfile)



import os
import sys
from selenium import webdriver

def to_png(url, outfile):
    folder = os.path.dirname(__file__)
    driver = webdriver.PhantomJS(service_log_path='/tmp/ghostdriver.log')
    driver.set_window_size(1024, 800)
    driver.get(url)
    driver.save_screenshot(outfile)
    driver.quit()




import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name='webpageshot',
    version='0.1',
    description='take screenshot of webpage ',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='Zhongqiang Shen',
    author_email='shenzhongqiang@msn.com',
    url='https://github.com/pythonml/webpageshot',
    packages=setuptools.find_packages(),
    install_requires=['selenium>=3.12.0'],
    classifiers=(
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ),
    entry_points={
        'console_scripts': [
            'webpageshot=webpageshot:main'
        ],
    },
)
